Parsl - Parallel Scripting Library
==================================
|licence| |build-status| |docs|

Parsl is a parallel scripting library that enables easy parallelism and workflow design.

.. |licence| image:: https://img.shields.io/badge/License-Apache%202.0-blue.svg
   :target: https://github.com/swift-lang/swift-e-lab/blob/master/LICENSE
   :alt: Apache Licence V2.0
.. |build-status| image:: https://travis-ci.org/swift-lang/swift-e-lab.svg?branch=master
   :target: https://travis-ci.org/swift-lang/swift-e-lab
   :alt: Build status
.. |docs| image:: https://readthedocs.org/projects/parsl/badge/?version=latest
   :target: http://parsl.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status


QuickStart
==========

1. Download Parsl::

    $ git clone https://github.com/swift-lang/swift-e-lab.git parsl

2. Install::

    $ cd parsl
    $ python3 setup.py install

3. Use Parsl!

Requirements
============

Parsl requires the following :

* Python 3.5+

For testing:

* nose
* coverage


